#include "mainwidget.h"
#include "ui_mainwidget.h"
#include "QDebug"

//Опредение функции для внедрения и использования в коде скрипта
//(устанавливает чередующиеся прописные и строчные буквы)
QScriptValue oddUpper(QScriptContext *context, QScriptEngine *engine) {
    QString value = context->argument(0).toString();
    QString res;
    for (int i = 0; i < value.length(); i++) {
        if ((i + 1)%2 == 1){
            res += value.at(i).toUpper();
        }
        else {
            res += value.at(i).toLower();
        }
    }
    return res;
}


MainWidget::MainWidget(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::MainWidget)
{
    ui->setupUi(this);

    //Создание объекта для внедрения функции с++ в скрипт
    QScriptValue oddUpperFunc = engine.newFunction(oddUpper);
    //Внедрение функции в движок скрипта
    engine.globalObject().setProperty("oddUpper", oddUpperFunc);
    //Создание объекта для внедрения объекта checkbox в скрипт
    QScriptValue checkbox = engine.newQObject(ui->checkBox);
    //Внедрение объекта checkbox в движок скрипта
    engine.globalObject().setProperty("checkbox", checkbox);
}

MainWidget::~MainWidget()
{
    delete ui;
}

void MainWidget::on_pushButton_clicked()
{
    //Берем код скрипта из текстового редактора на форме
    QString scriptCode = ui->teScript->toPlainText();

    //Создание объекта переменной для использования в скрипте
    QScriptValue prefix = engine.newVariant("Option ");
    //Объявление переменной в виде глобального свойства движка
    engine.globalObject().setProperty("prefix", prefix);
    //Запуск скрипта на выполнение
    QScriptValue result = engine.evaluate(scriptCode);

    //Проверка на возникновение ошибок при выполнении скрипта
    if (engine.hasUncaughtException()) {
        //Вывод сообщения об ошибке с указанием номера строки и причины
        QString errPattern = "line %1: %2";
        qDebug() << errPattern.arg(QString::number(engine.uncaughtExceptionLineNumber()), engine.uncaughtException().toString());
        return;
    }

    //Получение функции скрипта в виде объекта QScriptValue
    QScriptValue func = engine.globalObject().property("oddUpper");
    //Создание и инциализация списка аргументов для выхова функции
    QScriptValueList args;
    args << "String to be formatted";

    //Вывод результата выполнения функции скрипта в текстовый редактор teResult
    ui->teResult->setPlainText(func.call(QScriptValue(), args).toString());

    //Заполнение списка элементов combobox из результата выполнения скрипта
    QStringList values = result.toString().split(',');
    ui->comboBox->clear();
    ui->comboBox->addItems(values);
}
